@@ -29,7 +29,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 from skimage import data, img_as_float
-from skimage.filter import denoise_tv_chambolle, denoise_bilateral
+from skimage.restoration import denoise_tv_chambolle, denoise_bilateral
 
 
 lena = img_as_float(data.lena())
