@@ -22,11 +22,11 @@ fig, (ax0, ax1) = plt.subplots(ncols=2, figsize=(10, 4))
 img0 = ax0.imshow(image, cmap=plt.cm.gray)
 ax0.set_title('Image')
 ax0.axis('off')
-plt.colorbar(img0, ax=ax0)
+fig.colorbar(img0, ax=ax0)
 
 img1 = ax1.imshow(entropy(image, disk(5)), cmap=plt.cm.jet)
 ax1.set_title('Entropy')
 ax1.axis('off')
-plt.colorbar(img1, ax=ax1)
+fig.colorbar(img1, ax=ax1)
 
 plt.show()
