@@ -14,30 +14,31 @@ the intra-class variance.
 .. [1] http://en.wikipedia.org/wiki/Otsu's_method
 
 """
+import matplotlib
 import matplotlib.pyplot as plt
 
 from skimage.data import camera
 from skimage.filter import threshold_otsu
 
 
+matplotlib.rcParams['font.size'] = 9
+
+
 image = camera()
 thresh = threshold_otsu(image)
 binary = image > thresh
 
-plt.figure(figsize=(8, 2.5))
-plt.subplot(1, 3, 1)
-plt.imshow(image, cmap=plt.cm.gray)
-plt.title('Original')
-plt.axis('off')
+fig, (ax1, ax2, ax3) = plt.subplots(1, 3, figsize=(8, 2.5))
+ax1.imshow(image, cmap=plt.cm.gray)
+ax1.set_title('Original')
+ax1.axis('off')
 
-plt.subplot(1, 3, 2, aspect='equal')
-plt.hist(image)
-plt.title('Histogram')
-plt.axvline(thresh, color='r')
+ax2.hist(image)
+ax2.set_title('Histogram')
+ax2.axvline(thresh, color='r')
 
-plt.subplot(1, 3, 3)
-plt.imshow(binary, cmap=plt.cm.gray)
-plt.title('Thresholded')
-plt.axis('off')
+ax3.imshow(binary, cmap=plt.cm.gray)
+ax3.set_title('Thresholded')
+ax3.axis('off')
 
 plt.show()
