@@ -1,11 +1,11 @@
-from .exposure import histogram, equalize, equalize_hist, \
+from .exposure import histogram, equalize_hist, \
                       rescale_intensity, cumulative_distribution, \
                       adjust_gamma, adjust_sigmoid, adjust_log
 
 from ._adapthist import equalize_adapthist
 
+
 __all__ = ['histogram',
-           'equalize',
            'equalize_hist',
            'equalize_adapthist',
            'rescale_intensity',
