@@ -7,14 +7,21 @@ from skimage._shared.utils import deprecated
 
 
 __all__ = ['histogram', 'cumulative_distribution', 'equalize',
-           'rescale_intensity', 'adjust_gamma',
-           'adjust_log', 'adjust_sigmoid']
+           'rescale_intensity', 'adjust_gamma', 'adjust_log', 'adjust_sigmoid']
+
+
+DTYPE_RANGE = dtype_range.copy()
+DTYPE_RANGE.update((d.__name__, limits) for d, limits in dtype_range.items())
+DTYPE_RANGE.update({'uint10': (0, 2**10 - 1),
+                    'uint12': (0, 2**12 - 1),
+                    'uint14': (0, 2**14 - 1),
+                    'bool': dtype_range[np.bool_],
+                    'float': dtype_range[np.float64]})
 
 
 def histogram(image, nbins=256):
     """Return histogram of image.
 
-
     Unlike `numpy.histogram`, this function returns the centers of bins and
     does not rebin integer arrays. For integer arrays, each integer value has
     its own bin, which improves speed and intensity-resolution.
@@ -40,11 +47,12 @@ def histogram(image, nbins=256):
 
     Examples
     --------
-    >>> from skimage import data
-    >>> hist = histogram(data.camera())
-    >>> import matplotlib.pyplot as plt
-    >>> plt.plot(hist[1], hist[0])  # doctest: +ELLIPSIS
-    [...]
+    >>> from skimage import data, exposure, util
+    >>> image = util.img_as_float(data.camera())
+    >>> np.histogram(image, bins=2)
+    (array([107432, 154712]), array([ 0. ,  0.5,  1. ]))
+    >>> exposure.histogram(image, nbins=2)
+    (array([107432, 154712]), array([ 0.25,  0.75]))
     """
     sh = image.shape
     if len(sh) == 3 and sh[-1] < 4:
@@ -97,11 +105,6 @@ def cumulative_distribution(image, nbins=256):
     return img_cdf, bin_centers
 
 
-@deprecated('equalize_hist')
-def equalize(image, nbins=256):
-    return equalize_hist(image, nbins)
-
-
 def equalize_hist(image, nbins=256):
     """Return image after histogram equalization.
 
@@ -143,14 +146,15 @@ def rescale_intensity(image, in_range=None, out_range=None):
     ----------
     image : array
         Image array.
-    in_range : 2-tuple (float, float)
+    in_range : 2-tuple (float, float) or str
         Min and max *allowed* intensity values of input image. If None, the
         *allowed* min/max values are set to the *actual* min/max values in the
-        input image.
-    out_range : 2-tuple (float, float)
+        input image. Intensity values outside this range are clipped.
+        If string, use data limits of dtype specified by the string.
+    out_range : 2-tuple (float, float) or str
         Min and max intensity values of output image. If None, use the min/max
         intensities of the image data type. See `skimage.util.dtype` for
-        details.
+        details. If string, use data limits of dtype specified by the string.
 
     Returns
     -------
@@ -201,11 +205,14 @@ def rescale_intensity(image, in_range=None, out_range=None):
     if in_range is None:
         imin = np.min(image)
         imax = np.max(image)
+    elif in_range in DTYPE_RANGE:
+        imin, imax = DTYPE_RANGE[in_range]
     else:
         imin, imax = in_range
 
-    if out_range is None:
-        omin, omax = dtype_range[dtype]
+    if out_range is None or out_range in DTYPE_RANGE:
+        out_range = dtype if out_range is None else out_range
+        omin, omax = DTYPE_RANGE[out_range]
         if imin >= 0:
             omin = 0
     else:
@@ -263,7 +270,7 @@ def adjust_gamma(image, gamma=1, gain=1):
     dtype = image.dtype.type
 
     if gamma < 0:
-        return "Gamma should be a non-negative real number"
+        raise ValueError("Gamma should be a non-negative real number.")
 
     scale = float(dtype_limits(image, True)[1] - dtype_limits(image, True)[0])
 
@@ -339,7 +346,8 @@ def adjust_sigmoid(image, cutoff=0.5, gain=10, inv=False):
     References
     ----------
     .. [1] Gustav J. Braun, "Image Lightness Rescaling Using Sigmoidal Contrast
-    Enhancement Functions" http://www.cis.rit.edu/fairchild/PDFs/PAP07.pdf
+           Enhancement Functions",
+           http://www.cis.rit.edu/fairchild/PDFs/PAP07.pdf
 
     """
     _assert_non_negative(image)
