@@ -1,22 +1,29 @@
 from .lpi_filter import inverse, wiener, LPIFilter2D
-from .ctmf import median_filter
 from ._gaussian import gaussian_filter
 from ._canny import canny
 from .edges import (sobel, hsobel, vsobel, scharr, hscharr, vscharr, prewitt,
                     hprewitt, vprewitt, roberts, roberts_positive_diagonal,
                     roberts_negative_diagonal)
-from ._denoise import denoise_tv_chambolle
-from ._denoise_cy import denoise_bilateral, denoise_tv_bregman
 from ._rank_order import rank_order
 from ._gabor import gabor_kernel, gabor_filter
-from .thresholding import threshold_otsu, threshold_adaptive
+from .thresholding import (threshold_adaptive, threshold_otsu, threshold_yen,
+                           threshold_isodata)
 from . import rank
 
 
+from skimage._shared.utils import deprecated
+from skimage import restoration
+denoise_bilateral = deprecated('skimage.restoration.denoise_bilateral')\
+                        (restoration.denoise_bilateral)
+denoise_tv_bregman = deprecated('skimage.restoration.denoise_tv_bregman')\
+                        (restoration.denoise_tv_bregman)
+denoise_tv_chambolle = deprecated('skimage.restoration.denoise_tv_chambolle')\
+                        (restoration.denoise_tv_chambolle)
+
+
 __all__ = ['inverse',
            'wiener',
            'LPIFilter2D',
-           'median_filter',
            'gaussian_filter',
            'canny',
            'sobel',
@@ -37,6 +44,8 @@ __all__ = ['inverse',
            'rank_order',
            'gabor_kernel',
            'gabor_filter',
-           'threshold_otsu',
            'threshold_adaptive',
+           'threshold_otsu',
+           'threshold_yen',
+           'threshold_isodata',
            'rank']
