@@ -11,9 +11,9 @@ def configuration(parent_package='', top_path=None):
 
     config = Configuration('filter', parent_package, top_path)
     config.add_data_dir('tests')
+    config.add_data_dir('rank/tests')
 
     cython(['_ctmf.pyx'], working_path=base_path)
-    cython(['_denoise_cy.pyx'], working_path=base_path)
     cython(['rank/core_cy.pyx'], working_path=base_path)
     cython(['rank/generic_cy.pyx'], working_path=base_path)
     cython(['rank/percentile_cy.pyx'], working_path=base_path)
@@ -21,8 +21,6 @@ def configuration(parent_package='', top_path=None):
 
     config.add_extension('_ctmf', sources=['_ctmf.c'],
                          include_dirs=[get_numpy_include_dirs()])
-    config.add_extension('_denoise_cy', sources=['_denoise_cy.c'],
-        include_dirs=[get_numpy_include_dirs(), '../_shared'])
     config.add_extension('rank.core_cy', sources=['rank/core_cy.c'],
         include_dirs=[get_numpy_include_dirs()])
     config.add_extension('rank.generic_cy', sources=['rank/generic_cy.c'],
