@@ -1,7 +1,9 @@
 from .spath import shortest_path
-from .mcp import MCP, MCP_Geometric, route_through_array
+from .mcp import MCP, MCP_Geometric, MCP_Connect, MCP_Flexible, route_through_array
 
 __all__ = ['shortest_path',
            'MCP',
            'MCP_Geometric',
+           'MCP_Connect',
+           'MCP_Flexible',
            'route_through_array']
\ No newline at end of file
