@@ -6,12 +6,14 @@ try:
     from PIL import Image
 except ImportError:
     raise ImportError("The Python Image Library could not be found. "
-                      "Please refer to http://pypi.python.org/pypi/PIL/ "
+                      "Please refer to "
+                      "https://pypi.python.org/pypi/Pillow/ (or "
+                      "http://pypi.python.org/pypi/PIL/) "
                       "for further instructions.")
 
 from skimage.util import img_as_ubyte
 
-from skimage._shared import six
+from six import string_types
 
 
 def imread(fname, dtype=None):
@@ -106,10 +108,16 @@ def imsave(fname, arr, format_str=None):
         arr = arr.astype(np.uint8)
 
     # default to PNG if file-like object
-    if not isinstance(fname, six.string_types) and format_str is None:
+    if not isinstance(fname, string_types) and format_str is None:
         format_str = "PNG"
 
-    img = Image.fromstring(mode, (arr.shape[1], arr.shape[0]), arr.tostring())
+    try:
+        img = Image.frombytes(mode, (arr.shape[1], arr.shape[0]),
+                              arr.tostring())
+    except AttributeError:
+        img = Image.fromstring(mode, (arr.shape[1], arr.shape[0]),
+                               arr.tostring())
+
     img.save(fname, format=format_str)
 
 
