@@ -4,6 +4,7 @@ from numpy.testing import assert_array_equal, raises, run_module_suite
 import numpy as np
 
 import skimage.io as io
+from skimage.io.manage_plugins import plugin_store
 from skimage import data_dir
 
 
@@ -28,5 +29,17 @@ def test_imread_url():
     assert image.shape == (512, 512)
 
 
+@raises(RuntimeError)
+def test_imread_no_plugin():
+    # tweak data path so that file URI works on both unix and windows.
+    image_path = os.path.join(data_dir, 'lena.png')
+    plugins = plugin_store['imread']
+    plugin_store['imread'] = []
+    try:
+        io.imread(image_path)
+    finally:
+        plugin_store['imread'] = plugins
+
+
 if __name__ == "__main__":
     run_module_suite()
