@@ -1,11 +1,14 @@
-from .find_contours import find_contours
-from ._marching_cubes import marching_cubes, mesh_surface_area
+from ._find_contours import find_contours
+from ._marching_cubes import (marching_cubes, mesh_surface_area,
+                              correct_mesh_orientation)
 from ._regionprops import regionprops, perimeter
 from ._structural_similarity import structural_similarity
 from ._polygon import approximate_polygon, subdivide_polygon
 from ._moments import moments, moments_central, moments_normalized, moments_hu
+from .profile import profile_line
 from .fit import LineModel, CircleModel, EllipseModel, ransac
 from .block import block_reduce
+from ._label import label
 
 
 __all__ = ['find_contours',
@@ -23,6 +26,8 @@ __all__ = ['find_contours',
            'moments_central',
            'moments_normalized',
            'moments_hu',
-           'sum_blocks',
            'marching_cubes',
-           'mesh_surface_area']
+           'mesh_surface_area',
+           'correct_mesh_orientation',
+           'profile_line',
+           'label']
