@@ -4,10 +4,8 @@ from math import sqrt, atan2, pi as PI
 import numpy as np
 from scipy import ndimage
 
-from collections import MutableMapping
-
-from skimage.morphology import convex_hull_image, label
-from skimage.measure import _moments
+from ._label import label
+from . import _moments
 
 
 __all__ = ['regionprops', 'perimeter']
@@ -56,6 +54,8 @@ PROPS = {
     'WeightedNormalizedMoments': 'weighted_moments_normalized'
 }
 
+PROP_VALS = PROPS.values()
+
 
 class _cached_property(object):
     """Decorator to use a function as a cached property.
@@ -105,16 +105,15 @@ class _cached_property(object):
         return value
 
 
-class _RegionProperties(MutableMapping):
+class _RegionProperties(object):
 
     def __init__(self, slice, label, label_image, intensity_image,
-                 cache_active, properties=None):
+                 cache_active):
         self.label = label
         self._slice = slice
         self._label_image = label_image
         self._intensity_image = intensity_image
         self._cache_active = cache_active
-        self._properties = properties
 
     @_cached_property
     def area(self):
@@ -136,6 +135,7 @@ class _RegionProperties(MutableMapping):
 
     @_cached_property
     def convex_image(self):
+        from ..morphology.convex_hull import convex_hull_image
         return convex_hull_image(self.image)
 
     @_cached_property
@@ -304,46 +304,40 @@ class _RegionProperties(MutableMapping):
     def weighted_moments_normalized(self):
         return _moments.moments_normalized(self.weighted_moments_central, 3)
 
-
-    # Preserve dictionary interface
-    def __delitem__(self, key):
-        pass
-
-    def __len__(self):
-        return len(self._properties or PROPS.values())
-
-    def __setitem__(self, key, value):
-        raise RuntimeError("Cannot assign region properties.")
-
     def __iter__(self):
-        return iter(self._properties or PROPS.values())
+        return iter(PROPS.values())
 
     def __getitem__(self, key):
         value = getattr(self, key, None)
         if value is not None:
             return value
         else:  # backwards compatability
-            warnings.warn('Usage of deprecated property name.',
-                          category=DeprecationWarning)
             return getattr(self, PROPS[key])
 
+    def __eq__(self, other):
+        if not isinstance(other, _RegionProperties):
+            return False
 
-def regionprops(label_image, properties=None,
-                intensity_image=None, cache=True):
-    """Measure properties of labelled image regions.
+        for key in PROP_VALS:
+            try:
+                #so that NaNs are equal
+                np.testing.assert_equal(getattr(self, key, None),
+                                        getattr(other, key, None))
+            except AssertionError:
+                return False
+
+        return True
+
+
+def regionprops(label_image, intensity_image=None, cache=True):
+    """Measure properties of labeled image regions.
 
     Parameters
     ----------
     label_image : (N, M) ndarray
-        Labelled input image.
-    properties : {'all', list}
-        **Deprecated parameter**
-
-        This parameter is not needed any more since all properties are
-        determined dynamically.
-
+        Labeled input image.
     intensity_image : (N, M) ndarray, optional
-        Intensity image with same size as labelled image. Default is None.
+        Intensity image with same size as labeled image. Default is None.
     cache : bool, optional
         Determine whether to cache calculated properties. The computation is
         much faster for cached properties, whereas the memory consumption
@@ -351,9 +345,9 @@ def regionprops(label_image, properties=None,
 
     Returns
     -------
-    properties : list
-        List containing a properties for each region. The properties of each
-        region can be accessed as attributes and keys.
+    properties : list of RegionProperties
+        Each item describes one labeled region, and can be accessed using the
+        attributes listed below.
 
     Notes
     -----
@@ -399,7 +393,7 @@ def regionprops(label_image, properties=None,
     **major_axis_length** : float
         The length of the major axis of the ellipse that has the same
         normalized second central moments as the region.
-    **min_intensity** : float
+    **max_intensity** : float
         Value with the greatest intensity in the region.
     **mean_intensity** : float
         Value with the mean intensity in the region.
@@ -479,13 +473,16 @@ def regionprops(label_image, properties=None,
 
     Examples
     --------
-    >>> from skimage.data import coins
+    >>> from skimage import data, util
     >>> from skimage.morphology import label
-    >>> img = coins() > 110
+    >>> img = util.img_as_ubyte(data.coins()) > 110
     >>> label_img = label(img)
     >>> props = regionprops(label_img)
-    >>> props[0].centroid # centroid of first labelled object
-    >>> props[0]['centroid'] # centroid of first labelled object
+    >>> props[0].centroid # centroid of first labeled object
+    (22.729879860483141, 81.912285234465827)
+    >>> props[0]['centroid'] # centroid of first labeled object
+    (22.729879860483141, 81.912285234465827)
+
     """
 
     label_image = np.squeeze(label_image)
@@ -493,20 +490,17 @@ def regionprops(label_image, properties=None,
     if label_image.ndim != 2:
         raise TypeError('Only 2-D images supported.')
 
-    if properties is not None:
-        warnings.warn('The ``properties`` argument is deprecated and is '
-                      'not needed any more as properties are '
-                      'determined dynamically.',
-                      category=DeprecationWarning)
-
     regions = []
 
     objects = ndimage.find_objects(label_image)
     for i, sl in enumerate(objects):
+        if sl is None:
+            continue
+
         label = i + 1
 
-        props = _RegionProperties(sl, label, label_image,
-                                  intensity_image, cache, properties=properties)
+        props = _RegionProperties(sl, label, label_image, intensity_image,
+                                  cache)
         regions.append(props)
 
     return regions
