@@ -2,7 +2,7 @@ from .random_walker_segmentation import random_walker
 from ._felzenszwalb import felzenszwalb
 from .slic_superpixels import slic
 from ._quickshift import quickshift
-from .boundaries import find_boundaries, visualize_boundaries, mark_boundaries
+from .boundaries import find_boundaries, mark_boundaries
 from ._clear_border import clear_border
 from ._join import join_segmentations, relabel_from_one, relabel_sequential
 
@@ -12,7 +12,6 @@ __all__ = ['random_walker',
            'slic',
            'quickshift',
            'find_boundaries',
-           'visualize_boundaries',
            'mark_boundaries',
            'clear_border',
            'join_segmentations',
