@@ -15,6 +15,7 @@ def configuration(parent_package='', top_path=None):
 
     cython(['_hough_transform.pyx'], working_path=base_path)
     cython(['_warps_cy.pyx'], working_path=base_path)
+    cython(['_radon_transform.pyx'], working_path=base_path)
 
     config.add_extension('_hough_transform', sources=['_hough_transform.c'],
                          include_dirs=[get_numpy_include_dirs()])
@@ -22,6 +23,10 @@ def configuration(parent_package='', top_path=None):
     config.add_extension('_warps_cy', sources=['_warps_cy.c'],
                          include_dirs=[get_numpy_include_dirs(), '../_shared'])
 
+    config.add_extension('_radon_transform',
+                         sources=['_radon_transform.c'],
+                         include_dirs=[get_numpy_include_dirs()])
+
     return config
 
 if __name__ == '__main__':
