@@ -1,8 +1,9 @@
-import warnings
+from __future__ import division
 
 import numpy as np
-import scipy.ndimage as ndi
 from skimage.util.dtype import dtype_range
+from skimage import draw
+from skimage import measure
 
 from .plotplugin import PlotPlugin
 from ..canvastools import ThickLineTool
@@ -20,8 +21,6 @@ class LineProfile(PlotPlugin):
     ----------
     maxdist : float
         Maximum pixel distance allowed when selecting end point of scan line.
-    epsilon : float
-        Deprecated. Use `maxdist` instead.
     limits : tuple or {None, 'image', 'dtype'}
         (minimum, maximum) intensity limits for plotted profile. The following
         special values are defined:
@@ -35,10 +34,6 @@ class LineProfile(PlotPlugin):
     def __init__(self, maxdist=10, epsilon='deprecated',
                  limits='image', **kwargs):
         super(LineProfile, self).__init__(**kwargs)
-
-        if not epsilon == 'deprecated':
-            warnings.warn("Parameter `epsilon` deprecated; use `maxdist`.")
-            maxdist = epsilon
         self.maxdist = maxdist
         self._limit_type = limits
         print(self.help())
@@ -70,7 +65,11 @@ class LineProfile(PlotPlugin):
                                        on_change=self.line_changed)
         self.line_tool.end_points = np.transpose([x, y])
 
-        scan_data = profile_line(image, self.line_tool.end_points)
+        scan_data = measure.profile_line(image, 
+                                         *self.line_tool.end_points[:, ::-1])
+        self.scan_data = scan_data
+        if scan_data.ndim == 1:
+            scan_data = scan_data[:, np.newaxis]
 
         self.reset_axes(scan_data)
 
@@ -104,8 +103,12 @@ class LineProfile(PlotPlugin):
     def line_changed(self, end_points):
         x, y = np.transpose(end_points)
         self.line_tool.end_points = end_points
-        scan = profile_line(self.image_viewer.original_image, end_points,
-                            linewidth=self.line_tool.linewidth)
+        scan = measure.profile_line(self.image_viewer.original_image,
+                                    *end_points[:, ::-1],
+                                    linewidth=self.line_tool.linewidth)
+        self.scan_data = scan
+        if scan.ndim == 1:
+            scan = scan[:, np.newaxis]
 
         if scan.shape[1] != len(self.profile):
             self.reset_axes(scan)
@@ -131,79 +134,32 @@ class LineProfile(PlotPlugin):
                                         scan_data[:, 1], 'g-',
                                         scan_data[:, 2], 'b-')
 
+    def output(self):
+        """Return the drawn line and the resulting scan.
 
-def _calc_vert(img, x1, x2, y1, y2, linewidth):
-    # Quick calculation if perfectly horizontal
-    pixels = img[min(y1, y2): max(y1, y2) + 1,
-                 x1 - linewidth / 2: x1 + linewidth / 2 + 1]
+        Returns
+        -------
+        line_image : (M, N) uint8 array, same shape as image
+            An array of 0s with the scanned line set to 255.
+            If the linewidth of the line tool is greater than 1,
+            sets the values within the profiled polygon to 128.
+        scan : (P,) or (P, 3) array of int or float
+            The line scan values across the image.
+        """
+        end_points = self.line_tool.end_points
+        line_image = np.zeros(self.image_viewer.original_image.shape[:2],
+                              np.uint8)
+        width = self.line_tool.linewidth
+        if width > 1:
+            rp, cp = measure.profile._line_profile_coordinates(
+                *end_points[:, ::-1], linewidth=width)
+            # the points are aliased, so create a polygon using the corners
+            yp = np.rint(rp[[0, 0, -1, -1],[0, -1, -1, 0]]).astype(int)
+            xp = np.rint(cp[[0, 0, -1, -1],[0, -1, -1, 0]]).astype(int)
+            rp, cp = draw.polygon(yp, xp, line_image.shape)
+            line_image[rp, cp] = 128
+        (x1, y1), (x2, y2) = end_points.astype(int)
+        rr, cc = draw.line(y1, x1, y2, x2)
+        line_image[rr, cc] = 255
+        return line_image, self.scan_data
 
-    # Reverse index if necessary
-    if y2 > y1:
-        pixels = pixels[::-1, :]
-
-    return pixels.mean(axis=1)[:, np.newaxis]
-
-
-def profile_line(img, end_points, linewidth=1):
-    """Return the intensity profile of an image measured along a scan line.
-
-    Parameters
-    ----------
-    img : 2d or 3d array
-        The image, in grayscale (2d) or RGB (3d) format.
-    end_points: (2, 2) list
-        End points ((x1, y1), (x2, y2)) of scan line.
-    linewidth: int
-        Width of the scan, perpendicular to the line
-
-    Returns
-    -------
-    return_value : array
-        The intensity profile along the scan line. The length of the profile
-        is the ceil of the computed length of the scan line.
-    """
-    point1, point2 = end_points
-    x1, y1 = point1 = np.asarray(point1, dtype=float)
-    x2, y2 = point2 = np.asarray(point2, dtype=float)
-    dx, dy = point2 - point1
-    channels = 1
-    if img.ndim == 3:
-        channels = 3
-
-    # Quick calculation if perfectly vertical; shortcuts div0 error
-    if x1 == x2:
-        if channels == 1:
-            img = img[:, :, np.newaxis]
-
-        img = np.rollaxis(img, -1)
-        intensities = np.hstack([_calc_vert(im, x1, x2, y1, y2, linewidth)
-                                 for im in img])
-        return intensities
-
-    theta = np.arctan2(dy, dx)
-    a = dy / dx
-    b = y1 - a * x1
-    length = np.hypot(dx, dy)
-
-    line_x = np.linspace(x2, x1, np.ceil(length))
-    line_y = line_x * a + b
-    y_width = abs(linewidth * np.cos(theta) / 2)
-    perp_ys = np.array([np.linspace(yi - y_width,
-                                    yi + y_width, linewidth) for yi in line_y])
-    perp_xs = - a * perp_ys + (line_x + a * line_y)[:, np.newaxis]
-
-    perp_lines = np.array([perp_ys, perp_xs])
-    if img.ndim == 3:
-        pixels = [ndi.map_coordinates(img[..., i], perp_lines)
-                  for i in range(3)]
-        pixels = np.transpose(np.asarray(pixels), (1, 2, 0))
-    else:
-        pixels = ndi.map_coordinates(img, perp_lines)
-        pixels = pixels[..., np.newaxis]
-
-    intensities = pixels.mean(axis=1)
-
-    if intensities.ndim == 1:
-        return intensities[..., np.newaxis]
-    else:
-        return intensities
