@@ -1,12 +1,18 @@
 """
 ImageViewer class for viewing and interacting with images.
 """
-from ..qt import QtGui
+from ..qt import QtGui, qt_api
 from ..qt.QtCore import Qt, Signal
 
+if qt_api is not None:
+    has_qt = True
+else:
+    has_qt = False
+
 from skimage import io, img_as_float
 from skimage.util.dtype import dtype_range
 from skimage.exposure import rescale_intensity
+from skimage._shared.testing import doctest_skip_parser
 import numpy as np
 from .. import utils
 from ..widgets import Slider
@@ -20,12 +26,28 @@ __all__ = ['ImageViewer', 'CollectionViewer']
 def mpl_image_to_rgba(mpl_image):
     """Return RGB image from the given matplotlib image object.
 
-    Each image in a matplotlib figure has it's own colormap and normalization
+    Each image in a matplotlib figure has its own colormap and normalization
     function. Return RGBA (RGB + alpha channel) image with float dtype.
+
+    Parameters
+    ----------
+    mpl_image : matplotlib.image.AxesImage object
+        The image being converted.
+
+    Returns
+    -------
+    img : array of float, shape (M, N, 4)
+        An image of float values in [0, 1].
     """
-    input_range = (mpl_image.norm.vmin, mpl_image.norm.vmax)
-    image = rescale_intensity(mpl_image.get_array(), in_range=input_range)
-    image = mpl_image.cmap(img_as_float(image)) # cmap complains on bool arrays
+    image = mpl_image.get_array()
+    if image.ndim == 2:
+        input_range = (mpl_image.norm.vmin, mpl_image.norm.vmax)
+        image = rescale_intensity(image, in_range=input_range)
+        # cmap complains on bool arrays
+        image = mpl_image.cmap(img_as_float(image))
+    elif image.ndim == 3 and image.shape[2] == 3:
+        # add alpha channel if it's missing
+        image = np.dstack((image, np.ones_like(image)))
     return img_as_float(image)
 
 
@@ -56,8 +78,8 @@ class ImageViewer(QtGui.QMainWindow):
     --------
     >>> from skimage import data
     >>> image = data.coins()
-    >>> viewer = ImageViewer(image)
-    >>> # viewer.show()
+    >>> viewer = ImageViewer(image) # doctest: +SKIP
+    >>> viewer.show()               # doctest: +SKIP
 
     """
 
@@ -212,6 +234,7 @@ class ImageViewer(QtGui.QMainWindow):
         self._show()
         if main_window:
             utils.start_qtapp()
+        return [p.output() for p in self.plugins]
 
     def redraw(self):
         self.canvas.draw_idle()
